@@ -1,6 +1,8 @@
-pause <- function () 
+`pause` <-
+function () 
 {
     cat("Press <Enter> to continue...")
     readline()
     invisible()
 }
+
